pub struct RealFftC2cPlan<T: FftNum = f64> { /* private fields */ }Expand description
Complex-to-complex FFT plan (f64) backed by rustfft.
Both forward and inverse directions share a single scratch buffer sized to the larger of the two inplace scratch requirements.
Implementations