pub struct StftParams { /* private fields */ }Expand description
STFT parameters for spectrogram computation.
n_fft: Size of the FFT window.hop_size: Number of samples between successive frames.- window: Window function to apply to each frame.
- centre: Whether to pad the input signal so that frames are centered.
Implementations
Sourceimpl StftParams
impl StftParams
Sourcepub fn new(
n_fft: NonZeroUsize,
hop_size: NonZeroUsize,
window: WindowType,
centre: bool,
) -> SpectrogramResult<Self>
pub fn new( n_fft: NonZeroUsize, hop_size: NonZeroUsize, window: WindowType, centre: bool, ) -> SpectrogramResult<Self>
Create new STFT parameters.
Arguments
n_fft- Size of the FFT windowhop_size- Number of samples between successive frameswindow- Window function to apply to each framecentre- Whether to pad the input signal so that frames are centered
Errors
Returns an error if:
hop_size>n_fft- Custom window size doesn’t match
n_fft
Returns
New StftParams instance.
Sourcepub const fn n_fft(&self) -> NonZeroUsize
pub const fn n_fft(&self) -> NonZeroUsize
Sourcepub const fn hop_size(&self) -> NonZeroUsize
pub const fn hop_size(&self) -> NonZeroUsize
Sourcepub fn window(&self) -> WindowType
pub fn window(&self) -> WindowType
Sourcepub const fn centre(&self) -> bool
pub const fn centre(&self) -> bool
Get whether frames are centered (input signal is padded).
Returns
true if frames are centered, false otherwise.
Sourcepub fn builder() -> StftParamsBuilder
pub fn builder() -> StftParamsBuilder
Create a builder for STFT parameters.
Returns
A StftParamsBuilder instance.
Examples
use spectrograms::{StftParams, WindowType, nzu};
let stft = StftParams::builder()
.n_fft(nzu!(2048))
.hop_size(nzu!(512))
.window(WindowType::Hanning)
.centre(true)
.build()?;
assert_eq!(stft.n_fft(), nzu!(2048));
assert_eq!(stft.hop_size(), nzu!(512));Trait Implementations
Sourceimpl Clone for StftParams
impl Clone for StftParams
Sourcefn clone(&self) -> StftParams
fn clone(&self) -> StftParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StftParams
impl Debug for StftParams
Sourceimpl<'de> Deserialize<'de> for StftParams
impl<'de> Deserialize<'de> for StftParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PyStftParams> for StftParams
impl From<PyStftParams> for StftParams
Sourcefn from(val: PyStftParams) -> Self
fn from(val: PyStftParams) -> Self
Converts to this type from the input type.
Sourceimpl From<StftParams> for PyStftParams
impl From<StftParams> for PyStftParams
Sourcefn from(inner: StftParams) -> Self
fn from(inner: StftParams) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for StftParams
impl PartialEq for StftParams
Sourcefn eq(&self, other: &StftParams) -> bool
fn eq(&self, other: &StftParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StftParams
impl Serialize for StftParams
impl StructuralPartialEq for StftParams